@@ -2,23 +2,30 @@
 
 //! **noodles-csi** handles the reading and writing of the coordinate-sorted index (CSI) format.
 
+#[cfg(feature = "async")]
+pub mod r#async;
+
 pub mod binning_index;
 pub mod index;
 mod reader;
 mod writer;
 
-pub use self::{
-    binning_index::{BinningIndex, BinningIndexReferenceSequence},
-    index::Index,
-    reader::Reader,
-    writer::Writer,
-};
+pub use self::{binning_index::BinningIndex, index::Index, reader::Reader, writer::Writer};
+
+#[deprecated(
+    since = "0.4.0",
+    note = "Use `csi::binning_index::ReferenceSequenceExt` instead."
+)]
+pub use binning_index::ReferenceSequenceExt as BinningIndexReferenceSequence;
+
+#[cfg(feature = "async")]
+pub use self::r#async::{Reader as AsyncReader, Writer as AsyncWriter};
 
 use std::{fs::File, io, path::Path};
 
 static MAGIC_NUMBER: &[u8] = b"CSI\x01";
 
-/// Reads the entire contents of an coordinate-sorted index (CSI).
+/// Reads the entire contents of a coordinate-sorted index (CSI).
 ///
 /// This is a convenience function and is equivalent to opening the file at the given path and
 /// reading the index.
